@@ -4,6 +4,12 @@ Author  : Ajith Kumar B.P, bpajith@gmail.com
 License : GNU GPL version 3
 '''
 
+import gettext
+gettext.bindtextdomain("expeyes")
+gettext.textdomain('expeyes')
+_ = gettext.gettext
+
+
 from Tkinter import *
 import os, sys
 
@@ -14,8 +20,8 @@ NGRID1	= 10
 NGRID2  = 10
 BGCOL	  = 'white'
 PLOTBGCOL = 'white'
-LINEWIDTH = 2 
-LINECOL   = ['black', 'red', 'blue', 'green', 'cyan', 'magenta', 'yellow', 'orange','gray', 'gray2']
+LINEWIDTH = 1.5
+LINECOL   = ['black', 'red', 'blue', 'magenta', 'cyan', 'green', 'yellow', 'orange','gray', 'gray2']
 LABELCOL  = 'blue'
 TEXTCOL   = 'black'
 
@@ -42,8 +48,9 @@ class graph:
 	scaletext = []
 	markerval = []
 	markertext = None
-	xlabel = 'mSec'			# Default axis lables
+	xlabel = _('mSec')			# Default axis lables
 	ylabel = 'V'
+	markers = []
        
 	def __init__(self, parent, width=400., height=300.,color = 'white', labels = True, bip=True):
 		self.parent = parent
@@ -54,7 +61,7 @@ class graph:
 		self.bipolar = bip
 
 		if labels == False:
-			f = Frame(self.parent, bg = 'black', borderwidth = self.border, relief = FLAT)#SUNKEN)
+			f = Frame(self.parent, bg = 'black', borderwidth = self.border, relief = FLAT)
 			f.pack(side=TOP, anchor = S)
 			self.canvas = Canvas(f, bg = self.plotbg, width = width, height = height)
 			self.canvas.pack(side = TOP, anchor = S)
@@ -75,6 +82,17 @@ class graph:
 		self.setWorld(0 , 0, self.SCX, self.SCY, self.xlabel, self.ylabel)   # initialize scale factors 
 		self.grid()
 
+#----------------------- Another window ---------------------
+	def clear_fm(self):
+		try:
+			self.canvas.delete(self.msg_window)
+		except:
+			pass
+
+	def disp(self, msg):
+		self.clear_fm()
+		win = Button(text = msg, bg = 'yellow', fg='blue', font=("Helvetica", 30), command=self.clear_fm)
+		self.msg_window = self.canvas.create_window(self.SCX/4, self.SCY/10, window=win, anchor=NW)
 #--------------------------------- Manage the Marker's --------------------------------------
 	def enable_marker(self, marker_max = 3):
 		self.canvas.bind("<Button-3>", self.show_marker)
@@ -128,11 +146,11 @@ class graph:
 			self.scaletext = []
 		except:
 			pass
-		s = '%3.2f %s/div'%( (self.xmax-self.xmin)/NGRID1, xlabel)
+		s = _('%3.2f %s/div')%( (self.xmax-self.xmin)/NGRID1, xlabel)
 		t =  self.canvas.create_text(2, self.SCY*11/20, anchor = SW, justify = LEFT, \
 			fill = LABELCOL, text = s)
 		self.scaletext.append(t)
-		s = '%3.2f %s/div'%( (self.ymax-self.ymin)/NGRID1, ylabel)
+		s = _('%3.2f %s/div')%( (self.ymax-self.ymin)/NGRID1, ylabel)
 		t =  self.canvas.create_text(self.SCX/2, self.SCY-10,anchor = SW, justify = LEFT, \
 			fill = LABELCOL, text = s)
 		self.scaletext.append(t)
@@ -291,10 +309,19 @@ class graph:
 		self.traces = []
 #------------------------------- graph class end ---------------------------
 
-def plot(x,y):			# plot the x,y coordinate list to a new , non-blocking, window.
+def plot(x,y,title = None, xl = None, yl = None):
+	# plot the x,y coordinate list to a new , non-blocking, window.
+	if title==None:
+		title=_('EYES plot')
+	if xl==None:
+		xl=_('mS')
+	if yl==None:
+		yl=_('V')
 	w = Tk()
-	w.title('ExpEYES plot')
-	g = graph(w)
+	w.title(title)
+	g = graph(w, width=600, height=400)
+	g.xlabel = xl
+	g.ylabel = yl
 	g.auto_scale(x,y)
 	g.line(x,y)
 	return g
@@ -311,13 +338,13 @@ def abs_path():		   # Returns the absolute path of the python program
 		return '.' + os.sep
 
 img = None
-def pop_image(sch, title = 'Schematic'):
+def pop_image(sch, title = _('Schematic')):
 	global img   	
 	try:
 		import Image, ImageTk, tkFont
 		top = Toplevel()
 		Label(top,text=title,fg='blue').pack(side=TOP)
-		top.title('Schematic')
+		top.title(_('Schematic'))
 		im = Image.open(abs_path() + sch)
 		w,h= im.size
 		img = ImageTk.PhotoImage(im)
